PCB Environment: Palette Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Attributes
Palette Class Reference

## Public Member Functions
| Palette (const Color *, uint)
void | setColor (uint, Color)
uint | size () const
Color | operator[] (uint i) const

## Static Public Attributes
static Color | FootprintLine [2]
static Color | FootprintFill [2]
static Color | PinLine [2][2]
static Color | PinFill [2][2]
static Color | PowerNet
static Color | GroundNet
static Palette | Nets
static Palette | Tracks
static const uint | Hues [16]

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Color.hpp